# Documentation

Documentation for napkinXC is generated using [Sphinx](https://www.sphinx-doc.org/)
After each commit on `master`, documentation is updated and published to [Read the Docs](https://napkinxc.readthedocs.io).

You can build the documentation locally. Just install Sphinx and run in ``docs`` directory:

```
pip install -r requirements.txt
make html
```

Documentation will be created in `docs/_build` directory.